@@ -18,24 +18,41 @@ from .filesystem import get_created_files
 
 
 class CLIConfig(object):
-    """Invenio-cli configuration."""
+    """Invenio-cli configuration.
+
+    It provides a combined interface to the local CLI configuration which
+    is typically split between a
+        .invenio file with general project configuration
+        .invenio.private with per machine configuration
+                         (not version controlled)
+    """
 
     CONFIG_FILENAME = '.invenio'
+    PRIVATE_CONFIG_FILENAME = '.invenio.private'
     CLI_SECTION = 'cli'
     COOKIECUTTER_SECTION = 'cookiecutter'
     FILES_SECTION = 'files'
 
-    def __init__(self, fullpath=CONFIG_FILENAME, verbose=False):
+    def __init__(self, project_dir='./', verbose=False):
         """Constructor.
 
-        :param flavour: Flavour name.
+        :param config_dir: Path to general cli config file.
+        :param config_path: Absolute path to per machine cli config file.
         """
+        self.config_path = Path(project_dir) / self.CONFIG_FILENAME
         self.config = ConfigParser()
-        self.fullpath = fullpath
+        self.private_config_path = (
+            Path(project_dir) / self.PRIVATE_CONFIG_FILENAME
+        )
+        self.private_config = ConfigParser()
 
         try:
-            with open(fullpath) as cfg_file:
+            with open(self.config_path) as cfg_file:
                 self.config.read_file(cfg_file)
+
+            with open(self.private_config_path) as cfg_file:
+                self.private_config.read_file(cfg_file)
+
         except FileNotFoundError:
             click.secho(
                 "Missing '.invenio' file in current directory. "
@@ -45,30 +62,35 @@ class CLIConfig(object):
 
     def get_project_dir(self):
         """Returns path to project directory."""
-        return Path(self.config[CLIConfig.CLI_SECTION]['project_dir'])
+        return Path(self.private_config[CLIConfig.CLI_SECTION]['project_dir'])
 
     def get_instance_path(self):
         """Returns path to application instance directory."""
-        return Path(self.config[CLIConfig.CLI_SECTION]['instance_path'])
+        return Path(
+            self.private_config[CLIConfig.CLI_SECTION]['instance_path']
+        )
 
     def update_instance_path(self, new_instance_path):
         """Updates path to application instance directory."""
-        self.config[CLIConfig.CLI_SECTION]['instance_path'] = \
+        self.private_config[CLIConfig.CLI_SECTION]['instance_path'] = \
             str(new_instance_path)
 
-        with open(self.fullpath, 'w') as configfile:
-            self.config.write(configfile)
+        with open(self.private_config_path, 'w') as configfile:
+            self.private_config.write(configfile)
 
     def get_services_setup(self):
         """Returns bool whether services have been setup or not."""
-        return self.config.getboolean(CLIConfig.CLI_SECTION, 'services_setup')
+        return self.private_config.getboolean(
+            CLIConfig.CLI_SECTION, 'services_setup'
+        )
 
     def update_services_setup(self, is_setup):
         """Updates path to application instance directory."""
-        self.config[CLIConfig.CLI_SECTION]['services_setup'] = str(is_setup)
+        self.private_config[CLIConfig.CLI_SECTION]['services_setup'] = \
+            str(is_setup)
 
-        with open(self.fullpath, 'w') as configfile:
-            self.config.write(configfile)
+        with open(self.private_config_path, 'w') as configfile:
+            self.private_config.write(configfile)
 
     def get_project_shortname(self):
         """Returns the project's shortname."""
@@ -81,18 +103,16 @@ class CLIConfig(object):
         :param project_dir: Folder to write the config file into
         :param flavour: 'RDM' or 'ILS'
         :param replay: dict of cookiecutter replay
-        :return: full path to config file
+        :return: absolute Path to config (project) directory
         """
         config_parser = ConfigParser()
+        # Convert to absolute Path because simpler to reason about and pass
+        project_dir = Path(project_dir).resolve()
 
         # Internal to Invenio-cli section
         config_parser[cls.CLI_SECTION] = {}
         config_parser[cls.CLI_SECTION]['flavour'] = flavour
-        config_parser[cls.CLI_SECTION]['project_dir'] = project_dir
-        config_parser[cls.CLI_SECTION]['instance_path'] = ''
-        config_parser[cls.CLI_SECTION]['services_setup'] = str(False)
-        config_parser[cls.CLI_SECTION]['logfile'] = \
-            '{path}/logs/invenio-cli.log'.format(path=project_dir)
+        config_parser[cls.CLI_SECTION]['logfile'] = '/logs/invenio-cli.log'
 
         # Cookiecutter user input section
         config_parser[cls.COOKIECUTTER_SECTION] = {}
@@ -102,8 +122,18 @@ class CLIConfig(object):
         # Generated files section
         config_parser[cls.FILES_SECTION] = get_created_files(project_dir)
 
-        fullpath = Path(project_dir) / cls.CONFIG_FILENAME
-        with open(fullpath, 'w') as configfile:
+        config_path = project_dir / cls.CONFIG_FILENAME
+        with open(config_path, 'w') as configfile:
             config_parser.write(configfile)
 
-        return fullpath
+        # Internal to machine (not version controlled)
+        config_parser = ConfigParser()
+        config_parser[cls.CLI_SECTION] = {}
+        config_parser[cls.CLI_SECTION]['project_dir'] = str(project_dir)
+        config_parser[cls.CLI_SECTION]['instance_path'] = ''
+        config_parser[cls.CLI_SECTION]['services_setup'] = str(False)
+        private_config_path = project_dir / cls.PRIVATE_CONFIG_FILENAME
+        with open(private_config_path, 'w') as configfile:
+            config_parser.write(configfile)
+
+        return project_dir
